@@ -11,9 +11,9 @@ from trytond.model import (
     DeactivableMixin, Index, ModelSQL, ModelView, fields, sequence_ordered,
     tree)
 from trytond.pool import Pool
-from trytond.pyson import Bool, Eval, If, PYSONEncoder
+from trytond.pyson import Bool, Eval, If, PYSONEncoder, TimeDelta
 from trytond.tools import grouped_slice, reduce_ids
-from trytond.transaction import Transaction
+from trytond.transaction import Transaction, without_check_access
 
 from .exceptions import WorkProgressValidationError
 
@@ -144,8 +144,9 @@ class Work(sequence_ordered(), tree(separator='\\'), ModelSQL, ModelView):
             })
     timesheet_works = fields.One2Many(
         'timesheet.work', 'origin', 'Timesheet Works', readonly=True, size=1)
-    timesheet_available = fields.Function(
-        fields.Boolean('Available on timesheets'),
+    timesheet_available = fields.Function(fields.Boolean(
+            "Available on timesheets",
+            help="Check to record time spent."),
         'get_timesheet_available', setter='set_timesheet_available')
     timesheet_start_date = fields.Function(fields.Date('Timesheet Start',
             states={
@@ -161,7 +162,12 @@ class Work(sequence_ordered(), tree(separator='\\'), ModelSQL, ModelView):
             'company_work_time',
             help="Total time spent on this work and the sub-works."),
         'get_total')
-    effort_duration = fields.TimeDelta('Effort', 'company_work_time',
+    effort_duration = fields.TimeDelta(
+        "Effort", 'company_work_time',
+        domain=['OR',
+            ('effort_duration', '=', None),
+            ('effort_duration', '>=', TimeDelta()),
+            ],
         help="Estimated Effort for this work.")
     total_effort = fields.Function(fields.TimeDelta('Total Effort',
             'company_work_time',
@@ -540,7 +546,7 @@ class Work(sequence_ordered(), tree(separator='\\'), ModelSQL, ModelView):
         super(Work, cls).delete(project_works)
 
         if timesheet_works:
-            with Transaction().set_context(_check_access=False):
+            with without_check_access():
                 TimesheetWork.delete(timesheet_works)
 
     @classmethod
